==> outbreaks_1.3.0.tar.gz: outbreaks/NEWS.md <==
outbreaks 1.3.0 (2017-05-13)
==================

### NEW FEATURES

One new dataset added:<br>

* s_enteritidis_pt59 : Distribution network and genetic clusters of a food-borne
     outbreak of Salmonella Enteritidis PT59 (98 cases)


<br>
<br>

outbreaks 1.2.0 (2017-02-04)
==================

### NEW FEATURES

Several new datasets added:<br>

* dengue_fais_2011: Incidence of 157 clinical cases of Dengue fever on the island
  of Fais, Micronesia<br>
* dengue_yap_2011: Incidence of 978 clinical cases of Dengue fever on the Yap
  Main Islands, Micronesia<br>
* zika_girardot_2015: Incidence of 1936 clinical cases of Zika virus disease in
  Girardot, Colombia<br>
* zika_sanandres_2015: Incidence of 928 clinical cases of Zika virus disease in San
  Andres, Colombia<br>
* zika_yap_2007: Incidence of 108 clinical cases of Zika virus disease on the Yap
  Main Islands, Micronesia


### MINOR IMPROVEMENTS

* Bertrand Sudre (bertrand.sudre@edc.europa.eu) added as the
 contributor of the mers_korea_2015 dataset<br>
* Now using snake_case throughout


<br>
<br>

outbreaks 1.1.0 (2016-11-24)
==================

### NEW FEATURES

* mers.korea.2015 has been added to the collection of outbreak
  datasets; this describes the initial information collected by the
  Epidemic Intelligence group at European Centre for Disease
  Prevention and Control (ECDC) during the first weeks of the outbreak
  of Middle East respiratory syndrome (MERS-CoV) outbreak (South Korea) in 2015


<br>
<br>

outbreaks 1.0.0 (2016-10-31)
==================
First release of the outbreaks package on CRAN!

==> outbreaks_1.5.0.tar.gz: outbreaks/NEWS.md <==
outbreaks 1.5.0 (2018-12-15)
==================

### NEW FEATURES

One new dataset added:<br>

* `nipah_malaysia`: human cases of Nipah virus in Malaysia and Singapore, 1997-1999; data are weekly case counts, stratified by state / country


outbreaks 1.4.0
===============

### NEW FEATURES

* `rabies_car_2003`: dog rabies in Central African Republic, 2003-2012; data
comprise dates and locations of the cases, as well as viral sequences of the
pathogen for most cases



outbreaks 1.3.0 (2017-05-13)
==================

### NEW FEATURES

One new dataset added:<br>

* s_enteritidis_pt59: Distribution network and genetic clusters of a food-borne
     outbreak of Salmonella Enteritidis PT59 (98 cases)


<br>
<br>

outbreaks 1.2.0 (2017-02-04)
==================

### NEW FEATURES

Several new datasets added:<br>

* dengue_fais_2011: Incidence of 157 clinical cases of Dengue fever on the island
  of Fais, Micronesia<br>
* dengue_yap_2011: Incidence of 978 clinical cases of Dengue fever on the Yap
  Main Islands, Micronesia<br>
* zika_girardot_2015: Incidence of 1936 clinical cases of Zika virus disease in
  Girardot, Colombia<br>
* zika_sanandres_2015: Incidence of 928 clinical cases of Zika virus disease in San
  Andres, Colombia<br>
* zika_yap_2007: Incidence of 108 clinical cases of Zika virus disease on the Yap
  Main Islands, Micronesia


### MINOR IMPROVEMENTS

* Bertrand Sudre (bertrand.sudre@edc.europa.eu) added as the
 contributor of the mers_korea_2015 dataset<br>
* Now using snake_case throughout


<br>
<br>

outbreaks 1.1.0 (2016-11-24)
==================

### NEW FEATURES

* mers.korea.2015 has been added to the collection of outbreak
  datasets; this describes the initial information collected by the
  Epidemic Intelligence group at European Centre for Disease
  Prevention and Control (ECDC) during the first weeks of the outbreak
  of Middle East respiratory syndrome (MERS-CoV) outbreak (South Korea) in 2015


<br>
<br>

outbreaks 1.0.0 (2016-10-31)
==================
First release of the outbreaks package on CRAN!
